psychopy_ext.fmri.plot_timecourse — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.plot_timecourse

`psychopy_ext.fmri.` `plot_timecourse`(df, plt=None, cols='name', **kwargs)

  Plots an fMRI time course for signal change.

  Args: | df (`pandas.DataFrame`) A DataFrame with fMRI signal change computed.
  Kwargs: | title (str, default: ‘’) Title for the plot (i.e., for the current axis, not the whole figure) plt (`plot.Plot`, default: None) The plot you’re working on. cols (str or list of str, default: ‘name’) Column names to plot as separate conditions (different curves)